Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(491)

Unified Diff: net/http/transport_security_state_static.h

Issue 1535363003: Switch to standard integer types in net/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: stddef Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/transport_security_state.cc ('k') | net/http/url_security_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/transport_security_state_static.h
diff --git a/net/http/transport_security_state_static.h b/net/http/transport_security_state_static.h
index 3f61ae1e61577bcea977042e7fa96b432af90cbd..00e56873bdf4bac2525e816f891e531ded2a1d49 100644
--- a/net/http/transport_security_state_static.h
+++ b/net/http/transport_security_state_static.h
@@ -8,6 +8,8 @@
#ifndef NET_HTTP_TRANSPORT_SECURITY_STATE_STATIC_H_
#define NET_HTTP_TRANSPORT_SECURITY_STATE_STATIC_H_
+#include <stdint.h>
+
enum SecondLevelDomainName {
DOMAIN_NOT_PINNED,
DOMAIN_GOOGLE_COM,
@@ -728,10 +730,11 @@ static const struct Pinset kPinsets[] = {
// kHSTSHuffmanTree describes a Huffman tree. The nodes of the tree are pairs
// of uint8s. The last node in the array is the root of the tree. Each pair is
// two uint8 values, the first is "left" and the second is "right". If a uint8
// value has the MSB set then it represents a literal leaf value. Otherwise
// it's a pointer to the n'th element of the array.
-static const uint8 kHSTSHuffmanTree[] = {
+static const uint8_t kHSTSHuffmanTree[] = {
0xf0, 0xe4, 0x00, 0xf2, 0x01, 0x80, 0xf9, 0xe6, 0x03, 0xe7, 0xe9, 0x04,
0xb7, 0xb6, 0xb1, 0x06, 0xb0, 0xb3, 0x07, 0x08, 0x09, 0xea, 0xf8, 0x0a,
0x0b, 0xf7, 0xed, 0x0c, 0x0d, 0xef, 0x05, 0x0e, 0x02, 0x0f, 0xeb, 0xe2,
@@ -741,7 +744,7 @@ static const uint8 kHSTSHuffmanTree[] = {
0x16, 0x23, 0x14, 0x24, 0x10, 0x25,
};
-static const uint8 kPreloadedHSTSData[] = {
+static const uint8_t kPreloadedHSTSData[] = {
0xfe, 0xfb, 0x9b, 0x5b, 0xba, 0xcd, 0x11, 0x2a, 0xe0, 0x7e, 0x72, 0xf4,
0x85, 0xac, 0xe5, 0xdc, 0xf8, 0xe5, 0xff, 0xf4, 0x76, 0x24, 0x2e, 0xaf,
0x32, 0x8c, 0xf1, 0xcb, 0x9f, 0x47, 0x2a, 0x47, 0xfa, 0x11, 0x84, 0x4f,
@@ -728,10 +730,11 @@ static const struct Pinset kPinsets[] = {
// kHSTSHuffmanTree describes a Huffman tree. The nodes of the tree are pairs
// of uint8s. The last node in the array is the root of the tree. Each pair is
-// two uint8 values, the first is "left" and the second is "right". If a uint8
+// two uint8_t values, the first is "left" and the second is "right". If a
+// uint8_t
// value has the MSB set then it represents a literal leaf value. Otherwise
// it's a pointer to the n'th element of the array.
« no previous file with comments | « net/http/transport_security_state.cc ('k') | net/http/url_security_manager.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698